The same **Transport independence** concept of Seneca applies also for
Microservice's clients.

As we just see, with Seneca, you create microservices by calling `seneca.listen`.
To talk with the services we use `seneca.client`.

Both `seneca.client` and `seneca.listen` accept the following parameters:
* `port`: optional integer; port number.
* `host`: optional string; host IP address.
* `spec`: optional object; full specification object.

For instance, we can have this microservice:

```javascript
require('seneca')()
  .use( 'myplugin' )
  .listen( { type:'tcp'} )
```
...and a client:

```javascript
require('seneca')()
  .client({ type:'tcp'})
  .act({role: 'greetings', cmd: 'hello', name: 'Marco'}, console.log)
```

The goal of the exercise is to write a client for the previous `math` plugin using
the `sum` command exposed on TCP on the default port that prints on `console.log`
the microservice answer.

To solve the exercise create the solution which call the sum service using the first
two arguments (use `process.argv`).

Some Notes:

Since we have to require seneca, the seneca module must be available.
For that, just install it in the local folder using `npm i seneca`. That will
create a `node_modules` folder with seneca and all its dependencies.

If no `host` is specified, the client uses `0.0.0.0`. This will not work on
some versions of Windows. To fix that, simply specify `host: '127.0.0.1'` on
client connection.

Remember to `close` seneca when the client has received the answer, otherwise
the process will hang (and you have to terminate it manually).

If you want to test it manually, you can also change (or make a copy) of the solution
of the previous exercise and make it expose the microservice through TCP, launch
it with node and then launch your solution directly (`node program.js`).
